@@ -534,6 +534,7 @@ objinstptr newpageinst(objectptr pageobj)
    instancedefaults(newinst, pageobj, 0, 0);
    newinst->type = OBJINST;
    newinst->color = DEFAULTCOLOR;
+   newinst->style = NORMAL;	/* Do not scale linewidth with page scale */
    return newinst;
 }
 
@@ -1673,7 +1674,8 @@ void catalog_op(int op, int x, int y)
 		     *newselect = newinst;
 		     XcSetFunction(GXcopy);
 		     XcTopSetForeground(SELECTCOLOR);
-		     UDrawObject(*libobj, SINGLE, SELECTCOLOR, NULL);
+		     UDrawObject(*libobj, SINGLE, SELECTCOLOR,
+				xobjs.pagelist[areawin->page]->wirewidth, NULL);
 		  }
 	       }
 	       break;
