@@ -160,22 +160,23 @@ void geneasydraw(short instance, int mode, objectptr curobj, objinstptr curinst)
 
    switch (ELEMENTTYPE(*(curobj->plist + instance))) {
       case ARC:
-         UDrawArc((arcptr)elementptr);
+         UDrawArc((arcptr)elementptr, xobjs.pagelist[areawin->page]->wirewidth);
 	 break;
       case POLYGON:
-         UDrawPolygon((polyptr)elementptr);
+         UDrawPolygon((polyptr)elementptr, xobjs.pagelist[areawin->page]->wirewidth);
 	 break;
       case SPLINE:
-	 UDrawSpline((splineptr)elementptr);
+	 UDrawSpline((splineptr)elementptr, xobjs.pagelist[areawin->page]->wirewidth);
 	 break;
       case PATH:
-	 UDrawPath((pathptr)elementptr);
+	 UDrawPath((pathptr)elementptr, xobjs.pagelist[areawin->page]->wirewidth);
 	 break;
       case LABEL:
          UDrawString((labelptr)elementptr, mode, curinst);
 	 break;
       case OBJINST:
-         UDrawObject((objinstptr)elementptr, SINGLE, mode, NULL);
+         UDrawObject((objinstptr)elementptr, SINGLE, mode,
+			xobjs.pagelist[areawin->page]->wirewidth, NULL);
          break;
       case GRAPHIC:
          UDrawGraphic((graphicptr)elementptr);
@@ -903,7 +904,7 @@ Boolean selectarea(objectptr selobj, short level)
    genericptr   *curgen, *pathgen;
    Boolean	selected;
    stringpart	*strptr;
-   int		locpos, cx, cy;
+   int		locpos, cx, cy, hwidth, hheight;
    objinstptr	curinst;
    XPoint	saveorig, savesave, tmppt;
 
@@ -938,23 +939,22 @@ Boolean selectarea(objectptr selobj, short level)
 	    /* selected on a recursive area search.			*/
             savesave.x = areawin->save.x;
             savesave.y = areawin->save.y;
-            InvTransformPoints(&areawin->save, &tmppt, 1, curinst->position,
-			curinst->scale, curinst->rotation);
-            areawin->save.x = tmppt.x;
-            areawin->save.y = tmppt.y;
-
             saveorig.x = areawin->origin.x;
             saveorig.y = areawin->origin.y;
-            InvTransformPoints(&areawin->origin, &tmppt, 1, curinst->position,
-			curinst->scale, curinst->rotation);
-            areawin->origin.x = tmppt.x;
-            areawin->origin.y = tmppt.y;
 
-            UPushCTM();
-            UPreMultCTM(DCTM, curinst->position, curinst->scale,
-			curinst->rotation);
+	    areawin->save.x = (areawin->origin.x + areawin->save.x) / 2;
+	    areawin->save.y = (areawin->origin.y + areawin->save.y) / 2;
+
+            InvTransformPoints(&areawin->save, &tmppt, 1, curinst->position,
+			curinst->scale, curinst->rotation);
+	    hwidth = (savesave.x - saveorig.x) / (2 * curinst->scale);
+	    hheight = (savesave.y - saveorig.y) / (2 * curinst->scale);
+            areawin->save.x = tmppt.x + hwidth;
+            areawin->save.y = tmppt.y + hheight;
+            areawin->origin.x = tmppt.x - hwidth;
+            areawin->origin.y = tmppt.y - hheight;
+
             selected = selectarea(curinst->thisobject, level + 1);
-            UPopCTM();
             areawin->save.x = savesave.x;
             areawin->save.y = savesave.y;
             areawin->origin.x = saveorig.x;
@@ -999,7 +999,7 @@ Boolean selectarea(objectptr selobj, short level)
 			&(newboxpts[j].y), -1);
 	   }
 
-	   tmpext = ULength(slab, areawin->topinstance, 0.0, 0, NULL);
+	   tmpext = ULength(slab, areawin->topinstance, 0, NULL);
 	   adj.x = (slab->justify & NOTLEFT ? (slab->justify & RIGHT ? 
 			tmpext.width : tmpext.width >> 1) : 0);
 	   adj.y = (slab->justify & NOTBOTTOM ? (slab->justify & TOP ? 
@@ -1015,7 +1015,7 @@ Boolean selectarea(objectptr selobj, short level)
 	      if (locpos < 0) continue;	  /* only look at printable characters */
 	      if (strptr->type == RETURN) tmpl2 = 0;
 	      tmpl1 = tmpl2;
-	      tmpext = ULength(slab, areawin->topinstance, 0.0, j + 1, NULL);
+	      tmpext = ULength(slab, areawin->topinstance, j + 1, NULL);
 	      tmpl2 = tmpext.width;
 	      isect = test_insideness(((tmpl1 + tmpl2) >> 1) - adj.x,
 			(tmpext.base + (BASELINE >> 1)) - adj.y, newboxpts);
@@ -1295,10 +1295,8 @@ selection *recurselect(short class, u_char mode, pushlistptr *seltop)
 			"in new object is (%d, %d)\n",
 			savesave.x, savesave.y,
 			areawin->save.x, areawin->save.y); */
-         UPushCTM();
-         UPreMultCTM(DCTM, selinst->position, selinst->scale, selinst->rotation);
+
          rcheck = recurselect(ALL_TYPES, recmode, &selnew);
-         UPopCTM();
          areawin->save.x = savesave.x;
          areawin->save.y = savesave.y;
 
