@@ -5,7 +5,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 #include <math.h>
 #include <limits.h>
@@ -534,7 +533,6 @@ void SVGDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    short  oldx, oldfont, oldstyle;
    int olinerise = 4;
    float  tmpscale = 1.0, natscale = 1.0;
-   float  tmpthick = xobjs.pagelist[areawin->page]->wirewidth;
    XPoint newpoint;
    TextExtents tmpext;
    short *tabstops = NULL;
@@ -615,7 +613,7 @@ void SVGDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    fprintf(svgf, ">\n");
 
    /* "natural" (unscaled) length */
-   tmpext = ULength(drawlabel, localinst, 0.0, 0, NULL);
+   tmpext = ULength(drawlabel, localinst, 0, NULL);
 
    newpoint.x = (tmpjust & NOTLEFT ?
        (tmpjust & RIGHT ? -tmpext.width : -tmpext.width >> 1) : 0);
@@ -1062,8 +1060,6 @@ OutputSVG(char *filename, Boolean fullscale)
    UPopCTM();	/* Restore the top-level graphics state */
 }
 
-#ifdef TCL_WRAPPER
-
 /*----------------------------------------------------------------------*/
 /* The TCL command-line for the SVG file write routine.			*/
 /*----------------------------------------------------------------------*/
@@ -1111,6 +1107,4 @@ int xctcl_svg(ClientData clientData, Tcl_Interp *interp,
    return XcTagCallback(interp, objc, objv);
 }
 
-#endif /* TCL_WRAPPER */
-
 /*-------------------------------------------------------------------------*/
