@@ -1329,7 +1329,8 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
 /* draw a single character at 0, 0 using current transformation matrix */
 /*---------------------------------------------------------------------*/
 
-short UDrawChar(u_char code, short styles, short ffont, int groupheight, int passcolor)
+short UDrawChar(u_char code, short styles, short ffont, int groupheight,
+	int passcolor, float passwidth)
 {
    objectptr drawchar;
    XPoint alphapts[2];
@@ -1361,7 +1362,7 @@ short UDrawChar(u_char code, short styles, short ffont, int groupheight, int pas
 
    if (!(styles & 64)) {
       
-      UDrawObject(&charinst, SINGLE, passcolor, NULL);
+      UDrawObject(&charinst, SINGLE, passcolor, passwidth, NULL);
 
       /* under- and overlines */
       if (styles & 8)
@@ -1378,9 +1379,11 @@ short UDrawChar(u_char code, short styles, short ffont, int groupheight, int pas
 
 /*----------------------------------------------------------------------*/
 /* Draw an entire string, including parameter substitutions		*/
+/* (Normally called as UDrawString(); see below)			*/
 /*----------------------------------------------------------------------*/
 
-void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
+void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
+	Boolean drawX)
 {
    stringpart *strptr;
    char *textptr;
@@ -1388,8 +1391,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    int    pos, group = 0;
    int    defaultcolor, curcolor, scolor;
    short  oldx, oldfont, oldstyle;
-   float  tmpscale = 1.0, natscale = 1.0;
-   float  tmpthick = xobjs.pagelist[areawin->page]->wirewidth;
+   float  tmpscale = 1.0, natscale = 1.0, tmpthick = 2.0;
    XPoint newpoint, bboxin[2], bboxout[2];
    u_char xm, ym;
    TextExtents tmpext;
@@ -1426,7 +1428,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    tmpjust = flipadjust(drawlabel->justify);
 
    /* "natural" (unscaled) length */
-   tmpext = ULength(drawlabel, localinst, 0.0, 0, NULL);
+   tmpext = ULength(drawlabel, localinst, 0, NULL);
 
    newpoint.x = (tmpjust & NOTLEFT ?
        (tmpjust & RIGHT ? -tmpext.width : -tmpext.width >> 1) : 0);
@@ -1482,8 +1484,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 		
 		/* simple boldface technique for derived fonts */
 
-		xobjs.pagelist[areawin->page]->wirewidth =
-   		   ((fonts[ffont].flags & 0x21) == 0x21) ?  4.0 : 2.0;
+		tmpthick = ((fonts[ffont].flags & 0x21) == 0x21) ?  4.0 : 2.0;
 		break;
 
 	     case FONT_SCALE:
@@ -1590,7 +1591,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 		UPushCTM();
 		UPreMultCTM(DCTM, newpoint, tmpscale, 0);
 		addx = UDrawChar((u_char)32, fstyle, ffont, group,
-			curcolor);
+			curcolor, tmpthick);
 		newpoint.x += addx >> ((strptr->type == HALFSPACE) ? 1 : 2);
 		UPopCTM();
 		} break;
@@ -1628,7 +1629,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 		      }
 	           }
 	           newpoint.x += UDrawChar(*textptr, fstyle, ffont,
-			group, scolor) * tmpscale;
+			group, scolor, tmpthick) * tmpscale;
 
 		   UPopCTM();
 		}
@@ -1647,13 +1648,29 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 
    UPopCTM();
 
-   if (drawlabel->pin) UDrawXDown(drawlabel);
+   if (drawX && drawlabel->pin) UDrawXDown(drawlabel);
 
    if ((defaultcolor != DOFORALL) && (passcolor != curcolor)) {
       XTopSetForeground(passcolor);
    }
+}
 
-   xobjs.pagelist[areawin->page]->wirewidth = tmpthick;
+/*----------------------------------------------------------------------*/
+/* Draw String, with an "x" mark at the origin				*/
+/*----------------------------------------------------------------------*/
+
+void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
+{
+   UDrawString0(drawlabel, passcolor, localinst, TRUE);
+}
+
+/*----------------------------------------------------------------------*/
+/* Draw String, without the "x" mark					*/
+/*----------------------------------------------------------------------*/
+
+void UDrawStringNoX(labelptr drawlabel, int passcolor, objinstptr localinst)
+{
+   UDrawString0(drawlabel, passcolor, localinst, FALSE);
 }
 
 /*----------------------------------------------------------------------*/
@@ -1661,7 +1678,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 /*----------------------------------------------------------------------*/
 
 TextExtents ULength(labelptr drawlabel, objinstptr localinst,
-	float newscale, short dostop, XPoint *tbreak)
+	short dostop, XPoint *tbreak)
 {
    float oldscale, strscale, natscale, locscale = 1.0, xtotal = 0.5;
    float lasttotal = xtotal;
@@ -1681,8 +1698,7 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
    /* Don't draw temporary labels from schematic capture system */
    else if (drawlabel->string->type != FONT_NAME) return retext;
 
-   if (newscale > 0.0) natscale = UTopScale() * newscale;
-   else natscale = 1.0;
+   natscale = 1.0;
      
    oldscale = strscale = natscale;
 
@@ -1751,8 +1767,6 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
 	    strscale = natscale * strptr->data.scale;
 	    if (ykern == 0.0)
 	       natscale = strscale;
-   	    if (newscale > 0.0)
-	       strscale *= UTopScale();
 	    break;
 	 case KERN:
 	    xtotal += strptr->data.kern[0];
